.. rst-class:: detail

CustomInstruction
============================

.. currentmodule:: compas_rrc

.. autoclass:: CustomInstruction

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~CustomInstruction.__init__
        ~CustomInstruction.from_msg
    
    